@@ -15,7 +15,7 @@ Readonly::Array our @EXPORT_OK => qw(check_angle check_array check_array_object
 	check_number_of_items check_number_range check_regexp check_required
 	check_string check_string_begin check_strings);
 
-our $VERSION = 0.28;
+our $VERSION = 0.29;
 
 sub check_angle {
 	my ($self, $key) = @_;
@@ -680,7 +680,7 @@ Returns undef.
          Parameter '%s' must be a number.
                  Value: %s
 
- check_nuber_id():
+ check_number_id():
          Parameter '%s' must be a natural number.
                  Value: %s
 
@@ -1643,6 +1643,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.28
+0.29
 
 =cut
